@@ -1,5 +1,5 @@
 
-import unittest2 as unittest
+import unittest
 
 
 class TestSlimtaCore(unittest.TestCase):
