@@ -2,7 +2,7 @@ import sys
 from functools import wraps
 
 import unittest
-from mox3.mox import MoxTestBase, IsA
+from mox import MoxTestBase, IsA
 import gevent
 from gevent.pool import Pool
 from gevent.event import AsyncResult
