@@ -1,5 +1,5 @@
 import unittest
-from mox3.mox import MoxTestBase
+from mox import MoxTestBase
 from pycares.errno import ARES_ENOTFOUND, ARES_ENODATA
 
 from slimta.relay import PermanentRelayError
