@@ -1,5 +1,5 @@
 import unittest
-from mox3.mox import MoxTestBase, IgnoreArg
+from mox import MoxTestBase, IgnoreArg
 from gevent import socket
 
 from slimta import util
